xlwings - Make Excel fly with Python!
=====================================

xlwings (Open Source)
---------------------

xlwings is a `BSD-licensed <http://opensource.org/licenses/BSD-3-Clause>`_ Python library that makes it easy to call Python from Excel and vice versa:

* **Scripting**: Automate/interact with Excel from Python using a syntax that is close to VBA.
* **Macros**: Replace your messy VBA macros with clean and powerful Python code.
* **UDFs**: Write User Defined Functions (UDFs) in Python (Windows only).
* **REST API**: Expose your Excel workbooks via REST API.

**Numpy arrays** and **Pandas Series/DataFrames** are fully supported. xlwings-powered workbooks are easy to distribute and work
on **Windows** and **Mac**.

xlwings includes all files in the xlwings package except the ``pro`` folder, i.e. the ``xlwings.pro`` subpackage.

xlwings PRO
-----------

The purpose of xlwings PRO is to finance the continued maintenance and enhancement of xlwings. This will allow you to rely on the package without being left with the dreaded `"this library currently has no active maintainers" <https://github.com/python-excel/xlrd>`_ message that happens to too many open-source packages after a couple of years.

To get access to the additional functionality of xlwings PRO, you need a (trial) license key and at least xlwings v0.19.0. Everything under the ``xlwings.pro`` subpackage is distributed under a commercial license, see https://github.com/xlwings/xlwings/blob/master/LICENSE_PRO.txt.

* For current features and pricing: https://www.xlwings.org/pricing
* To request a trial license key: https://www.xlwings.org/trial

Links
-----

* Homepage: https://www.xlwings.org
* Quickstart: https://docs.xlwings.org/en/stable/quickstart.html
* Documentation: https://docs.xlwings.org
* Book (O'Reilly, 2021): https://www.xlwings.org/book
* Video Course: https://training.xlwings.org/p/xlwings
* Source Code: https://github.com/xlwings/xlwings


xltrail
-------

The Excel add-in is version controlled with `xltrail <https://www.xltrail.com>`_. You can see the diffs
`here <https://app.xltrail.com/#/?path=github.com%2FZoomerAnalytics%2Fxlwings.git&branch=master&public=true>`_.